+++
title = "Upload a large set of images"
description = "Massively uploading images directly to a Teklia IIIF server"

weight = 30
+++

TEKLIA provides a service to upload a large number of images directly on a [IIIF](https://iiif.io) image server. After the upload, the images are immediately available to be imported in Arkindex. This service is particularly useful when you do not already have a IIIF server hosting your images. The procedure to use this service is the following :

## Account creation

First you need to ask TEKLIA (you can reach us by email at `team@teklia.com` or on our [contact form](https://teklia.com/company/contact/) ) for the creation of an account on this service. You will  receive a user name (access-key) and a password (secret-key) by [wormhole.app](https://wormhole.app/)

{% warning() %}
The link on https://wormhole.app/  is valid only 24 hours. After this period, you will need to ask for a new link.
{% end %}

## Methods and clients for upload

| header | with graphical interfance | command line |
| ------ | ------ |------ |
| Windows | [Cyberduck](#upload-images-using-cyberduck), [WinSCP](#upload-images-using-winscp) | [aws](#upload-images-using-the-amazon-web-service-client-aws), [mc](#upload-images-using-the-minio-client-mc), [duck](#upload-images-using-the-cyberduck-cli) |
| Mac OSX | [Cyberduck](#upload-images-using-cyberduck) | [aws](#upload-images-using-the-amazon-web-service-client-aws), [mc](#upload-images-using-the-minio-client-mc), [duck](#upload-images-using-the-cyberduck-cli) |
| Linux | None | [aws](#upload-images-using-the-amazon-web-service-client-aws), [mc](#upload-images-using-the-minio-client-mc), [duck](#upload-images-using-the-cyberduck-cli) |

## Upload images using Cyberduck

[Cyberduck](https://cyberduck.io/) is a graphical application available on Microsoft Windows and Mac Os X.

1. install Cyberduck 
2. start Cyberduck
3. open a new connection and configure it:

   * select Amazon S3 type
   * enter the server address: `storage.teklia.com`
   * enter your **Access-Key**
   * entrer your **Secret access Key**
   * select "More option" and add your bucket_name as **Path**
   * connect

{{ figure(image="howto/large_upload/cyber1-1.png", height=500, caption="Cyberduck settings for storage.teklia.com") }}

4. you may be asked to enter your access key again at the first connection
{{ figure(image="howto/large_upload/cyber1-2.png", height=500, caption="Cyberduck settings for storage.teklia.com") }}

* you can organize your files in folders (create folder option in cyberduck)
{{ figure(image="howto/large_upload/cyber2.png", height=250, caption="Create folder in cyberduck") }}

* you can now drag and drop files to upload them to Teklia storage servers
{{ figure(image="howto/large_upload/cyber3.png", height=350, caption="Import files in cyberduck") }}


* you can check that the file are correctly transferred:
{{ figure(image="howto/large_upload/cyber4.png", height=350, caption="Check imported files in cyberduck") }}

⚠️ with Cyberduck you can't move external data, you need to copy it to the new location and then remove the old one.

## Upload images using WinSCP

For Windows systems, you can use [WinSCP](https://winscp.net/eng/download.php) which is also a graphical application for managing distant documents on S3 bucket.

1. install WinSCP
2. start WinSCP
3. Create a new connection and configure it:

   * select Amazon S3 protocol
   * enter the server address: `storage.teklia.com`
   * enter your **Access-key**
   * enter your **Secret-key**
{{ figure(image="howto/large_upload/winscp1.png", height=500, caption="WinSCP settings for storage.teklia.com") }}

   * in advanced options, select Environment > S3, and change **URL Style** in `Path` instead of virtual-host.
{{ figure(image="howto/large_upload/winscp2.png", height=500, caption="WinSCP settings for storage.teklia.com") }}

   * once you are connected, you need to select your bucket, click on `Open directory/Bookmark` or press `Ctrl + O`
{{ figure(image="howto/large_upload/winscp3.png", height=500, caption="WinSCP settings for storage.teklia.com") }}

   * enter your <bucket-name> and click ok to open your bucket
{{ figure(image="howto/large_upload/winscp4.png", height=500, caption="WinSCP settings for storage.teklia.com") }}

4. The left view represents your documents on your computer, the right one represents files in your bucket. Yu can upload by selecting documents and clicking `Upload` or with a drag and drop.
{{ figure(image="howto/large_upload/winscp5.png", height=500, caption="WinSCP settings for storage.teklia.com") }}

5. You can now create directories, list and delete documents.


## Upload images using the Cyberduck CLI

1. Install Cyberduck CLI using this documentation depending on which OS you are using https://trac.cyberduck.io/wiki/help/en/howto/cli
2. After installing the CLI, you should run the following command: `duck --upload s3://storage.teklia.com/<your-bucket> <PATH to your data>`
   * you should replace `<your-bucket>` with the name of your bucket
   * you should replace `<PATH to your data>` with the path to your data locally
3. You will be prompted to type your **Access-Key** which is your username
4. Once you provide your username, you will then be prompted to type your **Secret access Key**
5. The upload will then start and once it is done you will find your data in your bucket

⚠️ with Cyberduck CLI you can't move external data, you need to copy it to the new location and then remove the old one.

## Upload images using the Minio client `mc`

1. Install the Minio client binary following the documentation https://docs.min.io/docs/minio-client-quickstart-guide.html
2. After installing the CLI, you should create an alias : `mc alias set <alias-name> https://storage.teklia.com/ <access-key> <secret-key>`
   * you should replace `<alias-name>` with the name you want to use to call this specific service.
   * you should replace `<access-key>` and `<secret-key>` with your credentials
3. You can now list buckets and documents with the following command : `mc ls <alias-name>/<bucket-name>/<PATH>`
4. You can upload your files with the `mirror` command `mc mirror <your-file-or-directory> <alias-name>/<bucket-name>/<PATH>`
5. In order to download files, you can use `cp` command: `mc cp <alias-name>/<bucket-name>/<PATH> <your-file-or-directory>`
## Upload images using the Amazon Web Service client `aws`

1. Install the AWS client following the documentation https://docs.aws.amazon.com/cli/latest/userguide/getting-started-install.html
2. After installing the CLI, you should configure your client : `aws configure --profile=<profile_name>`
   * you will be asked for your `<access-key>` and `<secret-key>`.
   * leave the `Default region name` blank.
   * select an output format like `json`
3. You can now list buckets and documents with the following command : `aws --profile=<profile-name> --endpoint=https://storage.teklia.com/ s3 ls s3://<your-bucket>`
4. In order to upload files, you can use `sync` command: `aws --profile=<profile-name> --endpoint=https://storage.teklia.com/ s3 sync <directory> s3://<your-bucket>/`
5. You can also download your files with the same command `aws --profile=<profile-name> --endpoint=https://storage.teklia.com/ s3 sync s3://<your-bucket>/<directory> .`

## Using your images from the IIIF server

Once your images are uploaded on `storage.teklia.com`, they are immediately available through one of our IIIF servers.

For european customers, the IIIF base url is `https://europe-gamma.iiif.teklia.com/iiif/2`.

To get your image URL, you'll need two information:
- the storage bucket name (provided by Teklia and should be ending in `-data`)
- the image path on the bucket

You then need to concatenate all 3 parts: IIIF base url + bucket name + image path

Let's say you have uploaded the image `test.jpg` on the bucket `clientX-data`, then your IIIF image url will be: `https://europe-gamma.iiif.teklia.com/iiif/2/clientX-data%2Ftest.jpg`

### Folders

If you organized your content in folders, you need to [url-encode](https://www.urlencoder.org/) the image path from the sever root to follow the IIIF spec.

If you uploaded the image `project/folderX/imageY.png` in bucket `clientX-data`, then your IIIF image url will be `https://europe-gamma.iiif.teklia.com/iiif/2/clientX-data%2Fproject%2FfolderX%2FimageY.png`

### View the image

Finally to view the image in your web browser, and not only its metadata, you need to specify a [IIIF operation](https://iiif.io/api/image/3.0/#2-uri-syntax)

The simplest operation is to view the raw file without modification, as a JPEG (whatever your original file format): simply suffix your image url with `/full/full/0/default.jpg`.

So for the image `test.jpg` from `clientX-data` this becomes: `https://europe-gamma.iiif.teklia.com/iiif/2/clientX-data%2Ftest.jpg/full/full/0/default.jpg`

### Import to Arkindex

Once your content is organized, you can [import your images to Arkindex](@/howto/import_from_bucket/index.md).
