+++
title = "Entity"
weight = 50
+++

A **Named Entity** represents a real-world object inside Arkindex. It's linked to one or more `Element` through a `MetaData` or a `Transcription`.

## Rules

- An `Entity` must be of a type belonging to a set of `EntityType` which are defined at project level by project administrators.

{{ figure(image="content/project/entity/entity_types.png", height=400, caption="Entity type management panel in a Project") }}

- An `Entity` should be unique per project
	 - but we cannot enforce this at the database level, as we could have two different persons with the same name in a project.
- An `Entity` may be linked to an `Element` through a `MetaData`
   - For example, this is used to share a common location for several books
- An `Entity` may be linked to an `Element` through a `Transcription`
   - A single `Transcription` may have several `Entity` (for example 2 persons and a location)
   - A `TranscriptionEntity` is used to specify precisely where in the transcription text is situated the entity

<figure>

  ![Relationships between an entity and other objects in a Project](./entity_models.svg)

  <figcaption>Relationships between an entity and other objects in a Project</figcaption>
</figure>

## Web interface

Using Arkindex's web interface, you can view each entity and their usage on elements.

Contributors on a project are allowed to validate or reject entities usage on a transcription using the [`(Partial)UpdateEntity` API endpoint](https://demo.arkindex.org/api-docs/#tag/entities/operation/PartialUpdateEntity).

{{ figure(image="content/project/entity/entity_transcription.png", height=450, caption="Entities appear clearly on a transcription, with their type") }}

By clicking on an entity in the transcription you can access its dedicated page, which contains its details and links to elements.

{{ figure(image="content/project/entity/entity_details.png", height=450, caption="Entity details page") }}

## API Endpoints

These endpoints are the most useful to handle entities:

- [CreateEntity](https://demo.arkindex.org/api-docs/#operation/CreateEntity)
- [ListEntityElements](https://demo.arkindex.org/api-docs/#operation/ListEntityElements)
- [ListTranscriptionEntities](https://demo.arkindex.org/api-docs/#operation/ListTranscriptionEntities)
