+++
title = "Metadata"
weight = 20
+++

An element can be linked to multiple metadatas in order to add more context to the project.

Common use-cases are:
- creation dates,
- storage location,
- notes from a subject-matter expert
- Tables with various data

## Types

Arkindex supports a few types of Metadatas:

- `Text`, without formatting
- `Markdown`, for text that needs formatting such as tables, list, etc. (More information about [Markdown](https://www.markdownguide.org/))
- `Date`, for complete (year-month-day) or incomplete (just the year, or year-month) dates
- `Location`, to specify a place by name or GPS coordinates
- `Reference`, used internally during imports to point back to an external ID
- `Numeric`, for decimal numbers that can be filtered on with comparison operators
- `URL`, for HTTP or HTTPS links that will be made clickable

## Rules

- An **Element** can have several metadatas of the same type.
- An **Element** can have several metadatas of the same type and name, but they will be ordered.
- A metadata name can be up to 250 characters long.
- The types and names of metadatas are restricted by projects, and have to be set by a project administrator.
- A metadata with the type `URL` must be a valid URL starting with `http://` or `https://`.
- A metadata with the type `Date` must use a `YYYY-MM-DD`, `YYYY-MM` or `YYYY`, or declare a year interval with `YYYY-YYYY`.
- A metadata with the type `Numeric` must be a valid floating-point number.
- A metadata with the type `Markdown` can use Markdown syntax or a limited set of HTML tags. Special characters such as `&`, `<` and `>` will be escaped.

## Web interface

You can view an element metadata on the **Details** panel, when browsing a project. The metadata list is collapsed by default when browsing folders, but will automatically be displayed when viewing details of a single Element.

{{ figure(image="project/metadata-list.png", height=260, caption="View all the metadatas linked to an element") }}

If you have a write access on the project, you will also be able to add some metadatas using a simple form.

{{ figure(image="project/metadata-add.png", height=260, caption="Create a metadata on an element") }}

## API Endpoints

These endpoints are the most useful to handle Element metadatas:

- [ListElementMetaData](https://demo.arkindex.org/api-docs/#operation/ListElementMetaData)
- [CreateMetaData](https://demo.arkindex.org/api-docs/#operation/CreateMetaData)
- [RetrieveMetaData](https://demo.arkindex.org/api-docs/#operation/RetrieveMetaData)
- [DestroyMetaData](https://demo.arkindex.org/api-docs/#operation/DestroyMetaData)
