+++
title = "Type"
weight = 12
+++

Using appropriate types is crucial for a project, as it will ensure a clear structure between elements.

## Rules

- Arkindex do not assume any structure for a Project types, the Project administrator is free to create as many types as needed.
- **Type** has a unique (per project) identifying `slug`, which is used by API endpoints to simplify its usage (instead of using its ID)
- It also has a display name, which is only used for display purposes and has no restrictions
- A **Type** has a boolean `folder` attribute: when set to `True`, the web interface will always display the associated elements as a folder containing other elements, instead of displaying its details.

### Folders

Element types can also specify whether their elements are *folders*, which is
nothing more than a display option; the frontend will display folders as a
list of their child elements, whereas regular elements are expected to be on
an image.


## Default types

When creating a new project on Arkindex, you will get a pre-defined set of types:

- a folder named `Folder`
- `Page`
- `Paragraph`
- `Text line`
- `Text zone`
- `Word`

Feel free to change them as desired **before** importing your content.

## Historical books example

A project with historical books could have the following simple structure:

{{ figure(image="project/element-structure.png", height=450, caption="Example of Element structure for an historical project") }}

In this example, we have 4 different Element types:
- **Volume** is a folder, that will be used to group several elements of type **Page**
- **Page** represent a single page of a **Volume**. These elements will be directly linked to an image provided by the client.
- **Paragraph** will be created either by a human annotator, or by a Machine Learning tool. A **Paragraph** may span over several sections of **Page**.
- **Line** will generally be generated by a Machine Learning tool. In this case it could either be directly linked to a **Page** and/or a **Paragraph**.


## Web interface

As a project administrator, you can edit its types from the [project edition page](@/project/_index.md#web-interface).

You'll then get access to a table listing all the available types, and the different possible actions:
- Adding a new type (last line)
- Edit the display name, identifying slug, and folder type.

{{ figure(image="project/types.png", height=300, caption="Element Types management in the web interface") }}


## API Endpoints

Types are listed when retrieving a project from the API:
* [ListCorpus](https://demo.arkindex.org/api-docs/#operation/ListCorpus) to list types for all projects
* [RetrieveCorpus](https://demo.arkindex.org/api-docs/#operation/RetrieveCorpus) to list types of a single project
