+++
title = "Train a new model"
sort_by = "weight"
weight = 30
insert_anchor_links = "right"
+++

## Prepare your dataset archive(s)

Training **workers** requires two conditions from the datasets:
- the datasets state must be `Complete` (more information about the [dataset states](@/training/datasets/index.md#dataset-states)),
- the datasets must have an archive linked.

In order for these conditions to be fulfilled, you need to process your datasets with the [Training Dataset Extractor](https://demo.arkindex.org/process/workers/a6e68a73-a2d0-482e-bd79-46e0d0b3f045) **worker**, in a [dataset process][dataset-process]. This is done in two steps, detailed below.

### SQL export

In order to train a model in Arkindex, your first have to generate [an SQLite export](@/howto/export/index.md) of the project(s) your dataset(s) belong to.

{{ figure(image="howto/export/modal.png", height=341, caption="Completed project export") }}

### Generate the dataset archive(s)

When the export is ready, create a [dataset process][dataset-process] with the [Training Dataset Extractor](https://demo.arkindex.org/process/workers/a6e68a73-a2d0-482e-bd79-46e0d0b3f045) worker. This worker needs to be run over any dataset before it can be used for training. The dataset needs to be in either the `Open` or the `Error` state.

{{ figure(image="training/train-process/extract.png", height=500, caption="Process a dataset with the Training Dataset Extractor") }}

While this process is ongoing, the dataset's state will be updated to `Building`. Upon process completion, its state will be updated to either the `Complete` (success) or the `Error` state.

## Train a Machine Learning model

You can then create a new [dataset process][dataset-process], using the prepared datasets you need, with the actual training workers. The list of technologies we support for training in Arkindex is given in the next sections.

At the end of the training process, a new model version will be created. It will be available for download in the **My Models** menu, and available to workers that support models when [creating workers processes](@/howto/run_process/index.md).

### Doc-UFCN

[Doc-UFCN](https://gitlab.teklia.com/dla/doc-ufcn) is a model designed to perform Document Layout Analysis (DLA). Learn more about Doc-UFCN in our [blog post](https://teklia.com/blog/202201-docufcn-lib/).

To train a new Doc-UFCN model on a dataset, create a process with the [Doc-UFCN Training](https://demo.arkindex.org/process/workers/d287e14d-55bd-4b72-bb02-3eac5af9c690) worker.

Learn more about how to use this worker on its [description page](https://demo.arkindex.org/process/workers/d287e14d-55bd-4b72-bb02-3eac5af9c690).

{{ figure(image="training/train-process/doc_ufcn.png", height=500, caption="Training a Doc-UFCN model") }}

### YOLO v8

[YOLOv8](https://docs.ultralytics.com/) is the latest version of the [YOLO](https://arxiv.org/abs/1506.02640) object detection and image segmentation model. You can train YOLO models for the following tasks:
- [Object detection](https://docs.ultralytics.com/tasks/detect/),
- [Instance Segmentation](https://docs.ultralytics.com/tasks/segment/),
- [Image Classification](https://docs.ultralytics.com/tasks/classify/).

To train a new YOLO model for *Object detection* or *Instance Segmentation*, create a process with the [YOLO Training | Detect/Segment](https://demo.arkindex.org/process/workers/ba10ef9d-4f96-4245-910c-23387ce6921a) **worker**.

{{ figure(image="training/train-process/yolo_bbox_segment.png", height=500, caption="Training a YOLO model for Object detection/segmentation") }}

To train a new YOLO model for *Image Classification*, create a process with the [YOLO Training | Classify](https://demo.arkindex.org/process/workers/35956913-a355-4bf3-9b40-3000a3b6903d) **worker**.

{{ figure(image="training/train-process/yolo_classify.png", height=500, caption="Training a YOLO model for image classification") }}

### PyLaia

[PyLaia](https://atr.pages.teklia.com/pylaia/) is a model designed to perform Automatic Text Recognition (ATR).

To train a new PyLaia model on a dataset, create a process with the [PyLaia Training](https://demo.arkindex.org/process/workers/3370f2d9-d3fa-4e49-afa4-ea9e6875052f) worker.

Learn more about how to use this worker on its [description page](https://demo.arkindex.org/process/workers/3370f2d9-d3fa-4e49-afa4-ea9e6875052f).

{{ figure(image="training/train-process/pylaia.png", height=500, caption="Training a PyLaia model") }}


[dataset-process]: @/training/dataset-process/index.md